yakumo.nova.v2.security_group

Package yakumo :: Package nova :: Package v2 :: Module security_group |
[hide private]
[frames] | no frames]

# Module security_group

source code

Resource class and its manager for security groups in Compute API v2

Classes | [hide private]
| Resource Resource class for security groups in Compute API v2
| Manager Manager class for security groups in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('_rules', 'rules', mapper.Noop), ('
      project', 'tenant_id', mapper.Resource('project')),]